==> openssl_encrypt-0.3.3.tar.gz: openssl_encrypt-0.3.3/setup.py <==
from setuptools import setup, find_packages
import os

# Read the contents of your README file
this_directory = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name="openssl_encrypt",
    version="0.3.3",
    install_requires=[
	"cryptography>=42.0.0,<43.0.0",
    	"argon2-cffi>=23.1.0,<24.0.0",
    	"pywin32>=306,<307; sys_platform == 'win32'",
        "PyYAML",
    ],
    entry_points={
        'console_scripts': [
            'openssl-encrypt=openssl_encrypt.cli:main',
        ],
    },
    extras_require={
        "dev": [
            "pytest>=8.0.0",
            "pytest-cov>=4.1.0",
            "black>=24.1.0",
            "pylint>=3.0.0",
        ],
    },
    project_urls={
        "Bug Tracker": "https://gitlab.rm-rf.ch/world/openssl_encrypt/-/issues",
        "Documentation": "https://gitlab.rm-rf.ch/world/openssl_encrypt/-/tree/main/openssl_encrypt/docs",
        "Source Code": "https://gitlab.rm-rf.ch/world/openssl_encrypt/-/tree/main/openssl_encrypt",
    },
    packages=find_packages(),
    include_package_data=True,
    package_data={"": ["README.md"]},
    author="Tobi",
    author_email="jahlives@gmx.ch",
    description="A package for secure file encryption and decryption based on modern ciphers",
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords="encryption, decryption, random-password, secure shredding, security",
    url="https://gitlab.rm-rf.ch/world/openssl_encrypt",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
    	"Intended Audience :: Developers",
    	"Intended Audience :: End Users/Desktop",
    	"Intended Audience :: Information Technology",
    	"Intended Audience :: System Administrators",
        "Programming Language :: Python :: 3",
    	"Programming Language :: Python :: 3.9",
    	"Programming Language :: Python :: 3.10",
    	"Programming Language :: Python :: 3.11",
    	"Programming Language :: Python :: 3.12",
	"Programming Language :: Python :: 3.13",
        "License :: OSI Approved :: MIT License",
	"Topic :: Security",
	"Topic :: Security :: Cryptography",
    	"Topic :: Utilities",
    	"Operating System :: OS Independent",
    ],
    python_requires=">=3.9",
)

==> openssl_encrypt-0.4.1.tar.gz: openssl_encrypt-0.4.1/setup.py <==
from setuptools import setup, find_packages
import os

# Read the contents of your README file
this_directory = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name="openssl_encrypt",
    version="0.4.1",
    install_requires=[
	"cryptography>=42.0.0,<43.0.0",
    	"argon2-cffi>=23.1.0,<24.0.0",
    	"pywin32>=306,<307; sys_platform == 'win32'",
        "PyYAML",
    ],
    entry_points={
        'console_scripts': [
            'openssl-encrypt=openssl_encrypt.cli:main',
        ],
    },
    extras_require={
        "dev": [
            "pytest>=8.0.0",
            "pytest-cov>=4.1.0",
            "black>=24.1.0",
            "pylint>=3.0.0",
        ],
    },
    project_urls={
        "Bug Tracker": "https://gitlab.rm-rf.ch/world/openssl_encrypt/-/issues",
        "Documentation": "https://gitlab.rm-rf.ch/world/openssl_encrypt/-/tree/main/openssl_encrypt/docs",
        "Source Code": "https://gitlab.rm-rf.ch/world/openssl_encrypt/-/tree/main/openssl_encrypt",
    },
    packages=find_packages(),
    include_package_data=True,
    package_data={"": ["README.md"]},
    author="Tobi",
    author_email="jahlives@gmx.ch",
    description="A package for secure file encryption and decryption based on modern ciphers using heavy-compute-load chaining of hashing and KDF to generate strong encryption password based on users provided password to ensure secure encryption of files",
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords="encryption, decryption, random-password, secure shredding, security",
    url="https://gitlab.rm-rf.ch/world/openssl_encrypt",
    classifiers=[
        "Development Status :: 4 - Beta",
    	"Intended Audience :: Developers",
    	"Intended Audience :: End Users/Desktop",
    	"Intended Audience :: Information Technology",
    	"Intended Audience :: System Administrators",
        "Programming Language :: Python :: 3",
    	"Programming Language :: Python :: 3.9",
    	"Programming Language :: Python :: 3.10",
    	"Programming Language :: Python :: 3.11",
    	"Programming Language :: Python :: 3.12",
	"Programming Language :: Python :: 3.13",
        "License :: OSI Approved :: MIT License",
	"Topic :: Security",
	"Topic :: Security :: Cryptography",
    	"Topic :: Utilities",
    	"Operating System :: OS Independent",
    ],
    python_requires=">=3.9",
)
